# 安装
## 使用pip安装
```shell script
pip install -U liyi-cute
```
## 源码安装
```shell script
git clone https://github.com/daiyizheng/liyi-cute.git
python setup.py install
```
如果你需要手动安装这些依赖，可以查看下面的依赖列表：
- marshmallow>=3.15.0